Media model discovery methods.
Use model discovery as the source of truth for model keys, modes, required inputs, and public parameters. New Buble models can become available without an SDK release.
Summary
Functions
@spec list(Buble.Client.t(), keyword() | map()) :: {:ok, map()} | {:error, Buble.Error.t()}
@spec list!(Buble.Client.t(), keyword() | map()) :: map()